animation/splash_animation library

Classes

SplashAnimation
Configures a single animation step for the splash screen.

Enums

SplashAnimationType
Defines the type of animation to apply on the splash screen.