customContent property
A fully custom widget to use as the splash content. Requires layoutType = SplashLayoutType.custom.
Implementation
final Widget? customContent;
A fully custom widget to use as the splash content. Requires layoutType = SplashLayoutType.custom.
final Widget? customContent;