SplashState enum

Describes the current lifecycle state of the splash screen.

Inheritance
Available extensions

Values

initializing → const SplashState

The splash is initializing (running onInit).

animating → const SplashState

The splash is animating.

completed → const SplashState

The onInit callback has completed successfully.

error → const SplashState

An error occurred during initialization.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SplashState>
A constant List of the values in this enum, in order of their declaration.