SplashRouter class

Handles navigation after the splash screen completes.

Call navigate to push the resolved SplashRoute onto the navigator.

Constructors

SplashRouter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

Navigates to the given splashRoute using the provided context.
Navigates using a PageRouteBuilder for custom transition support.