SmartSplashKitPlatform class abstract

The interface that implementations of smart_splash_kit must implement.

Platform-specific implementations should extend this class.

Inheritance
  • Object
  • PlatformInterface
  • SmartSplashKitPlatform
Implementers

Constructors

SmartSplashKitPlatform()
Constructs a SmartSplashKitPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
Returns the current platform version string.
getSystemTheme() Future<String>
Returns the system theme: "light" or "dark".
keepSplashVisible() Future<void>
Signals native layer to keep splash visible.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeSplash() Future<void>
Signals native layer to remove the splash screen.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SmartSplashKitPlatform
The default instance of SmartSplashKitPlatform to use.
getter/setter pair