SmartSplashKitWeb class
Web implementation of SmartSplashKitPlatform.
- Inheritance
-
- Object
- PlatformInterface
- SmartSplashKitPlatform
- SmartSplashKitWeb
Constructors
- SmartSplashKitWeb()
- Constructs a SmartSplashKitWeb.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
Returns the current platform version string.
override
-
getSystemTheme(
) → Future< String> -
Returns the system theme: "light" or "dark".
override
-
keepSplashVisible(
) → Future< void> -
Signals native layer to keep splash visible.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeSplash(
) → Future< void> -
Signals native layer to remove the splash screen.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void - Registers this class as the default instance of SmartSplashKitPlatform.