menu
smart_splash_kit package
documentation
animation/splash_animation.dart
animation/splash_animation.dart
dark_mode
light_mode
animation/splash_animation
library
Classes
SplashAnimation
Configures a single animation step for the splash screen.
Enums
SplashAnimationType
Defines the type of animation to apply on the splash screen.
smart_splash_kit package
documentation
animation/splash_animation.dart
smart_splash_kit
package
Libraries
animation/splash_animation
config/splash_config
config/splash_config_parser
core/splash_controller
core/splash_router
loader/api_loader
smart_splash_kit
smart_splash_kit_platform_interface
smart_splash_kit_web
smart_splash_widget
theme/splash_theme
ui/splash_layout
ui/splash_widgets
splash_animation library