ApiLoader class
Utility class for running API calls during the splash screen.
Handles timeouts, retries, and internet connectivity checks.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
run<
T> (Future< T> operation(), {Duration timeout = const Duration(seconds: 10), int maxRetries = 0, Duration retryDelay = const Duration(seconds: 1)}) → Future<ApiLoadResult< T> > -
Runs an
operationwith atimeoutand up tomaxRetriesattempts. -
runAll(
List< Future Function()> operations, {Duration timeout = const Duration(seconds: 10)}) → Future<List< ApiLoadResult> > - Runs multiple API operations concurrently.